// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// Defines all the command-line switches used by the IPC infrastructure.

#ifndef IPC_IPC_SWITCHES_H_
#define IPC_IPC_SWITCHES_H_
#pragma once

#include "ipc/ipc_export.h"

namespace switches {

IPC_EXPORT extern const char kProcessChannelID[];
IPC_EXPORT extern const char kDebugChildren[];

}  // namespace switches

#endif  // IPC_IPC_SWITCHES_H_
